#include <iostream>
#include <set>
#include <cassert>
using namespace std;
using ll = long long;

struct point {
    ll x, y;

    point(ll x_, ll y_): x(x_), y(y_) {}

    point() {}

    bool operator<(const point pt) const {
        return x < pt.x || (x == pt.x && y < pt.y);
    }

    friend ostream& operator<<(ostream& o, point pt) {
        o << "(" << double(pt.x) / 2 << ' ' << double(pt.y) / 2 << ")";
        return o;
    }

    point operator+(const point pt) const {
        return {x + pt.x, y + pt.y};
    }

    point operator-() const {
        return {-x, -y};
    }

    point operator-(const point pt) const {
        return *this + (-pt);
    }

    ll operator*(const point pt) const {
        return x * pt.y - y * pt.x;
    }

    pair<point, point> intersect_y(ll y_) const {
        ll k = y_ - y;
        assert(k >= 0);
        return {{x - k, y_}, {x + k, y_}};
    }
};

bool is_covered(point p1, point p2) {
    return abs(p1.x - p2.x) <= abs(p1.y - p2.y);
}

point intersect(point l, point r) {
    return {(l.x + r.x + r.y - l.y) / 2, (r.x + r.y + l.y - l.x) / 2};
}

void erase_st(set<point>& st, point p, ll& sqr) {
    auto i = st.find(p);
    point pl;
    point pr;
    //point pl = *prev(i);
    //point pr = *next(i);
    //sqr -= pl * p;
    //sqr -= p * pr;
    //sqr -= pr * pl;
    st.erase(i);
}

void insert_st(set<point>& st, point p, ll& sqr) {
    st.insert(p);
    //auto i = st.find(p);
    //point pl = *prev(i);
    //point pr = *next(i);
    //sqr += pl * p;
    //sqr += p * pr;
    //sqr += pr * pl;
}

signed main() {
    ll n, m;
    cin >> n >> m;
    n *= 2, m *= 2;
    ll q;
    cin >> q;
    ll ans = 1ll * n * m;
    set<point> st;
    set<point> st_up;
    while (q--) {
        ll x, y;
        cin >> x >> y;
        x *= 2, y *= 2;
        st_up.insert({x, y});
        auto i = st_up.find({x, y});

        while (next(i) != st_up.end()) {
            if (is_covered({x, y}, *next(i))) {
                st_up.erase(next(i));
            } else {
                break;
            }
        }
        while (i != st_up.begin()) {
            if (is_covered({x, y}, *prev(i))) {
                st_up.erase(prev(i));
            } else {
                break;
            }
        }
        while (st.size() && st.rbegin()->x >= x) {
            auto j = st.lower_bound({x, y});
            if (is_covered(*i, *j)) {
                int sz = st.size();
                erase_st(st, *j, ans);
            } else {
                break;
            }
        }
        while (st.size() && st.begin()->x <= x) {
            auto j = prev(st.lower_bound({x + 1, -1}));

            if (is_covered(*i, *j)) {
                erase_st(st, *j, ans);
            } else {
                break;
            }
        }
        if (i == st_up.begin()) {
            if (i->x != 0) {
                point pl = i->intersect_y(m).first;
                if (pl.x < 0) {
                    pl = pl - point(pl.x, pl.x);
                }
                insert_st(st, pl, ans);
            }
        } else if (intersect(*prev(i), *i).y > m) {
            point p0 = prev(i)->intersect_y(m).second;
            point p1 = i->intersect_y(m).first;
            insert_st(st, p0, ans);
            insert_st(st, p1, ans);
        } else {
            point p = intersect(*prev(i), *i);
            insert_st(st, p, ans);
        }

        if (next(i) == st_up.end()) {
            if (i->x != n) {
                point pr = i->intersect_y(m).second;
                if (pr.x > n) {
                    pr = pr + point(n - pr.x, n - pr.x);
                }
                insert_st(st, pr, ans);
            }
        } else if (intersect(*i, *next(i)).y > m) {
            point p0 = i->intersect_y(m).second;
            point p1 = next(i)->intersect_y(m).first;
            insert_st(st, p0, ans);
            insert_st(st, p1, ans);
        } else {
            point p = intersect(*i, *next(i));
            insert_st(st, p, ans);
        }
        insert_st(st, *i, ans);
        ans = point(0, m) * (*st.begin()) + (*prev(st.end())) * point(n, m) + point(n, m) * point(0, m);
        for (auto i = st.begin(); next(i) != st.end(); ++i) {
            ans += (*i) * (*next(i));
        }
        assert(ans % 2 == 0);
        ans = n * m - ans / 2;
        cout << ans / 4;
        if (ans % 4 == 0) {
            cout << ".00";
        } else if (ans % 4 == 1) {
            cout << ".25";
        } else if (ans % 4 == 2) {
            cout << ".50";
        } else {
            cout << ".75";
        }
        cout << endl;
        //cout << ans / 4 << "." << setprecision(2) << double(ans % 4) / 4 << endl;
        //for (auto pt : st_up) {
            //cout << pt << ' ';
        //}
        //cout << endl;
        //for (auto pt0 : st)
            //cout << pt0 << ' ';
        //cout << endl << endl;
    }
}
