#include <iostream>
#include <set>
#include <cassert>
using namespace std;
using ll = long long;

struct point {
    ll x, y;

    point(ll x_, ll y_): x(x_), y(y_) {}

    point() {}

    bool operator<(const point pt) const {
        return x < pt.x || (x == pt.x && y < pt.y);
    }

    friend ostream& operator<<(ostream& o, point pt) {
        o << "(" << double(pt.x) / 2 << ' ' << double(pt.y) / 2 << ")";
        return o;
    }

    point operator+(const point pt) const {
        return {x + pt.x, y + pt.y};
    }

    point operator-() const {
        return {-x, -y};
    }

    point operator-(const point pt) const {
        return *this + (-pt);
    }

    ll operator*(const point pt) const {
        return x * pt.y - y * pt.x;
    }

    pair<point, point> intersect_y(ll y_) const {
        ll k = y_ - y;
        assert(k >= 0);
        return {{x - k, y_}, {x + k, y_}};
    }

    bool operator!=(const point pt) const {
        return x != pt.x || y != pt.y;
    }
};

bool is_covered(point p1, point p2) {
    return abs(p1.x - p2.x) <= p2.y - p1.y;
}

point intersect(point l, point r) {
    return {(l.x + r.x + r.y - l.y) / 2, (r.x + r.y + l.y - l.x) / 2};
}

void erase_st(set<point>& st, point p, ll& sqr, ll n, ll m) {
    auto i = st.find(p);
    point pl;
    if (i == st.begin()) {
        pl = point(0, m);
    } else {
        pl = *prev(i);
    }
    point pr;
    if (next(i) == st.end()) {
        pr = point(n, m);
    } else {
        pr = *next(i);
    }
    if (pl != point(0, m) || pr != point(n, m)) {
        sqr -= pl * p;
        sqr -= p * pr;
        sqr -= pr * pl;
    }
    st.erase(i);
}

void insert_st(set<point>& st, point p, ll& sqr, ll n, ll m) {
    st.insert(p);
    auto i = st.find(p);
    point pl;
    if (i == st.begin()) {
        pl = point(0, m);
    } else {
        pl = *prev(i);
    }
    point pr;
    if (next(i) == st.end()) {
        pr = point(n, m);
    } else {
        pr = *next(i);
    }
    if (pl != point(0, m) || pr != point(n, m)) {
        sqr -= pl * p;
        sqr -= p * pr;
        sqr -= pr * pl;
    }
}

signed main() {
    ll n, m;
    cin >> n >> m;
    n *= 2, m *= 2;
    ll q;
    cin >> q;
    ll ans = point(n, m) * point(0, m);
    set<point> st;
    set<point> st_up;
    while (q--) {
        ll x, y;
        cin >> x >> y;
        x *= 2, y *= 2;
        bool aa = false;
        for (auto [x0, y0] : st_up) {
            if (is_covered({x0, y0}, {x, y})) {
                aa = true;
                break;
            }
        }
        if (aa || y == m)
            continue;
        st_up.insert({x, y});
        auto i = st_up.find({x, y});

        while (next(i) != st_up.end()) {
            if (is_covered({x, y}, *next(i))) {
                st_up.erase(next(i));
            } else {
                break;
            }
        }
        while (i != st_up.begin()) {
            if (is_covered({x, y}, *prev(i))) {
                st_up.erase(prev(i));
            } else {
                break;
            }
        }
        while (st.size() && st.rbegin()->x >= x) {
            auto j = st.lower_bound({x, y});
            if (is_covered(*i, *j)) {
                int sz = st.size();
                erase_st(st, *j, ans, n, m);
            } else {
                break;
            }
        }
        while (st.size() && st.begin()->x <= x) {
            auto j = prev(st.lower_bound({x + 1, -1}));
            if (is_covered(*i, *j)) {
                erase_st(st, *j, ans, n, m);
            } else {
                break;
            }
        }
        if (i == st_up.begin()) {
            if (i->x != 0) {
                point pl = i->intersect_y(m).first;
                if (pl.x < 0) {
                    pl = pl - point(pl.x, -pl.x);
                }
                insert_st(st, pl, ans, n, m);
            }
        } else if (intersect(*prev(i), *i).y > m) {
            point p0 = prev(i)->intersect_y(m).second;
            point p1 = i->intersect_y(m).first;
            insert_st(st, p0, ans, n, m);
            insert_st(st, p1, ans, n, m);
        } else {
            point p = intersect(*prev(i), *i);
            insert_st(st, p, ans, n, m);
        }

        if (next(i) == st_up.end()) {
            if (i->x != n) {
                point pr = i->intersect_y(m).second;
                if (pr.x > n) {
                    pr = pr + point(n - pr.x, n - pr.x);
                }
                insert_st(st, pr, ans, n, m);
            }
        } else if (intersect(*i, *next(i)).y > m) {
            point p0 = i->intersect_y(m).second;
            point p1 = next(i)->intersect_y(m).first;
            insert_st(st, p0, ans, n, m);
            insert_st(st, p1, ans, n, m);
        } else {
            point p = intersect(*i, *next(i));
            insert_st(st, p, ans, n, m);
        }
        insert_st(st, *i, ans, n, m);

        //ans = point(0, m) * (*st.begin()) + (*prev(st.end())) * point(n, m) + point(n, m) * point(0, m);
        //for (auto i = st.begin(); next(i) != st.end(); ++i) {
            //point p = (*i) - (*next(i));
            //ans += (*i) * (*next(i));
        //}
        ll ans_ = n * m - ans / 2;
        //ans = n * m - ans / 2;
        cout << ans_ / 4;
        if (ans_ % 4 == 0) {
            cout << ".00";
        } else if (ans_ % 4 == 1) {
            cout << ".25";
        } else if (ans_ % 4 == 2) {
            cout << ".50";
        } else {
            cout << ".75";
        }
        cout << endl;
    }
}
